@@ -5,7 +5,7 @@ use warnings;
 use strict;
 use 5.010001;
 
-our $VERSION = '1.111';
+our $VERSION = '1.112';
 
 use Win32::Console       qw( STD_INPUT_HANDLE ENABLE_MOUSE_INPUT ENABLE_PROCESSED_INPUT
                              RIGHT_ALT_PRESSED LEFT_ALT_PRESSED RIGHT_CTRL_PRESSED LEFT_CTRL_PRESSED SHIFT_PRESSED );
@@ -121,14 +121,13 @@ sub __reset_mode {
         $self->{input}->Flush;
         # workaround Bug #33513:
         delete $self->{input}{handle};
-        #$self->{input}{handle} = undef;
         #
     }
 }
 
 
 sub __get_term_size {
-    my ( $self, $handle_out ) = @_;  # no use for $handle_out on win32
+    my ( $self ) = @_;
     my ( $term_width, $term_height ) = Win32::Console->new()->Size();
     return $term_width - 1, $term_height;
 }
@@ -159,7 +158,7 @@ Term::Choose::Win32 - Plugin for Term::Choose.
 
 =head1 VERSION
 
-Version 1.111
+Version 1.112
 
 =head1 DESCRIPTION
 
